@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Data::Rx;
 # ABSTRACT: perl implementation of Rx schema system
-$Data::Rx::VERSION = '0.200006';
+$Data::Rx::VERSION = '0.200007';
 use Data::Rx::Util;
 use Data::Rx::TypeBundle::Core;
 
@@ -42,9 +42,41 @@ use Data::Rx::TypeBundle::Core;
 #pod When required, see L<Data::Rx::Manual::CustomTypes> for details on creating a
 #pod custom type plugin as a Perl module.
 #pod
+#pod =head1 SCHEMA METHODS
+#pod
+#pod The objects returned by C<make_schema> should provide the methods detailed in
+#pod this section.
+#pod
+#pod =head2 check
+#pod
+#pod   my $ok = $schema->check($input);
+#pod
+#pod This method just returns true if the input is valid under the given schema, and
+#pod false otherwise.  For more information, see C<assert_valid>.
+#pod
+#pod =head2 assert_valid
+#pod
+#pod   $schema->assert_valid($input);
+#pod
+#pod This method will throw an exception if the input is not valid under the schema.
+#pod The exception will be a L<Data::Rx::FailureSet>.  This has two important
+#pod methods: C<stringify> and C<failures>.  The first provides a string form of the
+#pod failure.  C<failures> returns a list of L<Data::Rx::Failure> objects.
+#pod
+#pod Failure objects have a few methods of note:
+#pod
+#pod   error_string - a human-friendly description of what went wrong
+#pod   stringify    - a stringification of the error, data, and check string
+#pod   error_types  - a list of types for the error; like tags
+#pod
+#pod   data_string  - a string describing where in the input the error occured
+#pod   value        - the value found at the data path
+#pod
+#pod   check_string - a string describing which part of the schema found the error
+#pod
 #pod =head1 SEE ALSO
 #pod
-#pod L<http://rjbs.manxome.org/rx>
+#pod L<http://rx.codesimply.com/>
 #pod
 #pod =cut
 
@@ -278,7 +310,7 @@ Data::Rx - perl implementation of Rx schema system
 
 =head1 VERSION
 
-version 0.200006
+version 0.200007
 
 =head1 SYNOPSIS
 
@@ -391,17 +423,73 @@ for how to teach your Rx schema object about the new types you create.
 When required, see L<Data::Rx::Manual::CustomTypes> for details on creating a
 custom type plugin as a Perl module.
 
+=head1 SCHEMA METHODS
+
+The objects returned by C<make_schema> should provide the methods detailed in
+this section.
+
+=head2 check
+
+  my $ok = $schema->check($input);
+
+This method just returns true if the input is valid under the given schema, and
+false otherwise.  For more information, see C<assert_valid>.
+
+=head2 assert_valid
+
+  $schema->assert_valid($input);
+
+This method will throw an exception if the input is not valid under the schema.
+The exception will be a L<Data::Rx::FailureSet>.  This has two important
+methods: C<stringify> and C<failures>.  The first provides a string form of the
+failure.  C<failures> returns a list of L<Data::Rx::Failure> objects.
+
+Failure objects have a few methods of note:
+
+  error_string - a human-friendly description of what went wrong
+  stringify    - a stringification of the error, data, and check string
+  error_types  - a list of types for the error; like tags
+
+  data_string  - a string describing where in the input the error occured
+  value        - the value found at the data path
+
+  check_string - a string describing which part of the schema found the error
+
 =head1 SEE ALSO
 
-L<http://rjbs.manxome.org/rx>
+L<http://rx.codesimply.com/>
 
 =head1 AUTHOR
 
 Ricardo SIGNES <rjbs@cpan.org>
 
+=head1 CONTRIBUTORS
+
+=for stopwords Hakim Cassimally Ronald J Kimball
+
+=over 4
+
+=item *
+
+Hakim Cassimally <hakim@mysociety.org>
+
+=item *
+
+Ronald J Kimball <rjk@tamias.net>
+
+=item *
+
+Ronald J Kimball <rkimball@pangeamedia.com>
+
+=item *
+
+Ronald J Kimball <rkimball@snapapp.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Ricardo SIGNES.
+This software is copyright (c) 2015 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
