@@ -2,7 +2,15 @@ use strict;
 use warnings;
 package Data::Rx::FailureSet;
 # ABSTRACT: multiple structured failure reports from an Rx checker
-$Data::Rx::FailureSet::VERSION = '0.200006';
+$Data::Rx::FailureSet::VERSION = '0.200007';
+#pod =head1 SYNOPSIS
+#pod
+#pod This is what is thrown when a schema's C<assert_valid> method finds a problem
+#pod with the input.  For more information on it, look at the documentation for
+#pod L<Data::Rx>.
+#pod
+#pod =cut
+
 use overload '""' => \&stringify;
 
 sub new {
@@ -140,7 +148,13 @@ Data::Rx::FailureSet - multiple structured failure reports from an Rx checker
 
 =head1 VERSION
 
-version 0.200006
+version 0.200007
+
+=head1 SYNOPSIS
+
+This is what is thrown when a schema's C<assert_valid> method finds a problem
+with the input.  For more information on it, look at the documentation for
+L<Data::Rx>.
 
 =head1 AUTHOR
 
@@ -148,7 +162,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Ricardo SIGNES.
+This software is copyright (c) 2015 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
